Calculate Oakey's heritability from model object
H2_Oakey.RdCompute heritability for genotype means using the variance–covariance matrix of the genotype BLUPs as described by Oakey et al. (2006).
Usage
h2_Oakey(model,
target,
options = NULL,
marginal = TRUE,
stratification = NULL,
vc = NULL,
...)
H2_Oakey(model,
target,
options = NULL,
marginal = TRUE,
stratification = NULL,
vc = NULL,
...)Arguments
- model
Model object of class
lmerMod/merModorasreml- target
The name of the random effect for which heritability is to be calculated.
- options
NULL by default, for internal checking of model object before calculations
- marginal
Logical; if
TRUE, construct marginal (strata-averaged) mappings so that each genotype receives a single averaged effect per term. IfFALSE, mappings will only consider the main genotype effect and ignore the iteracting terms.- stratification
A one-row data frame defining the stratum in which genotype effects should be evaluated. The columns must correspond to model terms that interact with
target.- vc
A list of precomputed variance components. Should be in the same structure as the output of
var_comp()- ...
Additional arguments that specify heritability calculation when interactions with genotype effects are modelled
Details
$$h^2_{Oakey} = \frac{\sum_{i = n_z+1}^{n_g} \lambda_i}{\sum_{n_g}^{\lambda_i\neq 0}}$$ where:
\(n_g\) is the number of genotypes
\(n_z\) is the number of zero eigenvalues
\(\lambda_i\) is the ith eigenvalue of the matrix \(I_{m} - G^{-1}C^{gg}\)
\(\sigma^2\) is the variance attributed to differences between genotype
See pages 813 and 818 of the reference for full derivation and explanation for Oakey's heritability