Calculate Piepho's heritability using variance parameters
H2_Piepho_parameters.RdCompute Piepho's heritability using the variance of differences between two BLUES.
Details
The equation for Piepho's heritability is as follows:
$$H^2_{Piepho} = \frac{\sigma^2_g}{\sigma^2_g + \overline{PEV_{BLUE_g}} / 2}$$
where:
\(\overline{PEV_{BLUE_g}}\) is the prediction error variance matrix for genotype BLUEs
\(\sigma^2_g\) is the variance attributed to differences between genotype