Fixed-effects-only fitted values from an asreml model
get_fixed_fit_asreml.RdReturns the fitted values based on fixed effects only (\(\hat{y} = X\hat{\beta}\)), excluding all random effects.
Usage
get_fixed_fit_asreml(model, source = list())Arguments
- model
An object of class
"asreml", fitted withmodel.frame = TRUE.- source
The known genomic relationship matrix (GRM) used in
modelfitted usingasreml::vm(), provided as a named list. When not provided (an empty list by default), the GRM variable used forvmcalling will be searched in the global environment.